joker
=====

Base classes and utilities for a joker-style project skeleton.


Other projects under `joker` namespace by the same author:

    joker-aligner
    joker-bioinfo
    joker-broker
    joker-cast
    joker-diskcache
    joker-flasky
    joker-geometry
    joker-masquerade
    joker-minions
    joker-nightly
    joker-pyoneliner
    joker-scraper
    joker-stream
    joker-studio
    joker-superuser
    joker-textmanip
    joker-xopen

